@@ -8,9 +8,34 @@ __all__ = ["dopen",
            ]
 
 from io import DEFAULT_BUFFER_SIZE
+from os.path import dirname
 from typing import Union, List, Any
 
 
+def add_sys_path_if_not(add_path: str, sys_path: List[str]):
+	"""
+	Добавить путь если его нет
+	:param add_path: 
+	:param sys_path: 
+	:return: 
+	"""
+	if add_path not in sys_path:
+		sys_path.append(add_path)
+
+
+def rel_path(slice_end: int, add_path: str = ""):
+	"""
+	Обрезает относительный путь, и может добавлять к нему другой путь:
+	:param slice_end: Срез с конца
+	:param add_path: Добавить путь
+	:return:
+	"""
+	p = dirname(__file__).replace("\\", "/").split("/")[:slice_end]
+	if add_path:
+		p.append(add_path.replace("\\", "/"))
+	return "/".join(p)
+
+
 class StyleText:
 	def __init__(self, present_text: str, style_text: str):        ...
 
